==> gimp-1.3.1.tar.bz2: gimp-1.3.1/app/core/gimpdrawable-blend.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef  __GIMP_DRAWABLE_BLEND_H__
#define  __GIMP_DRAWABLE_BLEND_H__


void   gimp_drawable_blend (GimpDrawable     *drawable,
                            BlendMode         blend_mode,
                            gint              paint_mode,
                            GradientType      gradient_type,
                            gdouble           opacity,
                            gdouble           offset,
                            RepeatMode        repeat,
                            gint              supersample,
                            gint              max_depth,
                            gdouble           threshold,
                            gdouble           startx,
                            gdouble           starty,
                            gdouble           endx,
                            gdouble           endy,
                            GimpProgressFunc  progress_callback,
                            gpointer          progress_data);


#endif /* __GIMP_DRAWABLE_BLEND_H__ */

==> gimp-1.3.12.tar.bz2: gimp-1.3.12/app/core/gimpdrawable-blend.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattis
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef  __GIMP_DRAWABLE_BLEND_H__
#define  __GIMP_DRAWABLE_BLEND_H__


void   gimp_drawable_blend (GimpDrawable     *drawable,
                            GimpBlendMode     blend_mode,
                            gint              paint_mode,
                            GimpGradientType  gradient_type,
                            gdouble           opacity,
                            gdouble           offset,
                            GimpRepeatMode    repeat,
                            gint              supersample,
                            gint              max_depth,
                            gdouble           threshold,
                            gdouble           startx,
                            gdouble           starty,
                            gdouble           endx,
                            gdouble           endy,
                            GimpProgressFunc  progress_callback,
                            gpointer          progress_data);


#endif /* __GIMP_DRAWABLE_BLEND_H__ */
